:orphan:
:og:image: ./_images/ogp/main.png
:og:image:alt: Title section for demo presentation

===============================
Introduction of sphinx-revealjs
===============================

:Based version: 2.5.0
:Demo updated: 2022-11-13

Overview
========

What is this?
-------------

Sphinx extension to build Reveal.js presentation

Features
--------

.. This is reST comment. At default, does not write.

* Convert sections from reStructuredText directly
* Support customize sections
* Support using plugins
* Support Sphinx extensions
* Select theme from default themes

.. include:: _sections/standard-usage.rst
.. include:: _sections/rst-to-revealjs.rst
.. include:: _sections/customize-section.rst
.. include:: _sections/interactive-content.rst
.. include:: _sections/using-plugins.rst

Enjoy writing reST as presentation
==================================

Please star!

.. raw:: html

    <!-- Place this tag where you want the button to render. -->
    <a class="github-button" href="https://github.com/attakei/sphinx-revealjs" data-icon="octicon-star" data-size="large" data-show-count="true" aria-label="Star attakei/sphinx-revealjs on GitHub">Star</a>
    <!-- Place this tag in your head or just before your close body tag. -->
    <script async defer src="https://buttons.github.io/buttons.js"></script>
